==> haskell-options-1.2.1.2-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-options.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-options-z-options-internal
version:              1.2.1.2
package-name:         options
lib-name:             options-internal
id:                   options-1.2.1.2-FsQdMuTKQV46V8Aqk7W2W2-options-internal
key:                  options-1.2.1.2-FsQdMuTKQV46V8Aqk7W2W2-options-internal
license:              MIT
maintainer:           Chris Martin <chris@typeclasses.com>
author:               John Millikin <john@john-millikin.com>
stability:            stable
homepage:             https://github.com/typeclasses/options/
synopsis:             Powerful and easy command-line option parser
description:
    Lets library and application developers easily work with command-line options.

category:             Console
abi:                  77b70bf99e075281b43fc8a0f3295d1f
exposed-modules:
    Options.Help Options.Tokenize Options.Types Options.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-options
hs-libraries:         HSoptions-1.2.1.2-FsQdMuTKQV46V8Aqk7W2W2-options-internal
depends:
    base-4.17.2.1 containers-0.6.7
    monads-tf-0.3.0.0-Jjm9WixioF17dCgga1aucS

haddock-interfaces:   /usr/share/doc/haskell-options/html/options.haddock
haddock-html:         /usr/share/doc/haskell-options/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 options
version:              1.2.1.2
visibility:           public
id:                   options-1.2.1.2-3mhNGrfiPrpBPvkXYTtQhP
key:                  options-1.2.1.2-3mhNGrfiPrpBPvkXYTtQhP
license:              MIT
maintainer:           Chris Martin <chris@typeclasses.com>
author:               John Millikin <john@john-millikin.com>
stability:            stable
homepage:             https://github.com/typeclasses/options/
synopsis:             Powerful and easy command-line option parser
description:
    Lets library and application developers easily work with command-line options.

category:             Console
abi:                  02a7276999d7af1368ac8370fcc11e05
exposed:              True
exposed-modules:      Options
import-dirs:          /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-options
hs-libraries:         HSoptions-1.2.1.2-3mhNGrfiPrpBPvkXYTtQhP
depends:
    base-4.17.2.1 containers-0.6.7
    monads-tf-0.3.0.0-Jjm9WixioF17dCgga1aucS
    options-1.2.1.2-FsQdMuTKQV46V8Aqk7W2W2-options-internal

haddock-interfaces:   /usr/share/doc/haskell-options/html/options.haddock
haddock-html:         /usr/share/doc/haskell-options/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-options-1.2.1.2-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-options.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-options-z-options-internal
version:              1.2.1.2
package-name:         options
lib-name:             options-internal
id:                   options-1.2.1.2-16YU7lY6R7OJkYY9Rs819j-options-internal
key:                  options-1.2.1.2-16YU7lY6R7OJkYY9Rs819j-options-internal
license:              MIT
maintainer:           Chris Martin <chris@typeclasses.com>
author:               John Millikin <john@john-millikin.com>
stability:            stable
homepage:             https://github.com/typeclasses/options/
synopsis:             Powerful and easy command-line option parser
description:
    Lets library and application developers easily work with command-line options.

category:             Console
abi:                  70ec980c5e3753c52f01daed8b79521b
exposed-modules:
    Options.Help Options.Tokenize Options.Types Options.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-options
hs-libraries:         HSoptions-1.2.1.2-16YU7lY6R7OJkYY9Rs819j-options-internal
depends:
    base-4.17.2.1 containers-0.6.7
    monads-tf-0.3.0.0-Jjm9WixioF17dCgga1aucS

haddock-interfaces:   /usr/share/doc/haskell-options/html/options.haddock
haddock-html:         /usr/share/doc/haskell-options/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 options
version:              1.2.1.2
visibility:           public
id:                   options-1.2.1.2-J4zbGzlVjtc18NW9gqAT5T
key:                  options-1.2.1.2-J4zbGzlVjtc18NW9gqAT5T
license:              MIT
maintainer:           Chris Martin <chris@typeclasses.com>
author:               John Millikin <john@john-millikin.com>
stability:            stable
homepage:             https://github.com/typeclasses/options/
synopsis:             Powerful and easy command-line option parser
description:
    Lets library and application developers easily work with command-line options.

category:             Console
abi:                  3a9d9645fbe1b255a79244134a395d95
exposed:              True
exposed-modules:      Options
import-dirs:          /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/options-1.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-options
hs-libraries:         HSoptions-1.2.1.2-J4zbGzlVjtc18NW9gqAT5T
depends:
    base-4.17.2.1 containers-0.6.7
    monads-tf-0.3.0.0-Jjm9WixioF17dCgga1aucS
    options-1.2.1.2-16YU7lY6R7OJkYY9Rs819j-options-internal

haddock-interfaces:   /usr/share/doc/haskell-options/html/options.haddock
haddock-html:         /usr/share/doc/haskell-options/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
